package com.huimv.env.common.service.impl;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.common.utils.DataUill;
import com.huimv.env.common.entity.BasePigpen;
import com.huimv.env.common.entity.EnergyData;
import com.huimv.env.common.entity.EnergyWater;
import com.huimv.env.common.entity.dto.PigpenDto;
import com.huimv.env.common.entity.vo.EnergyWaterDataVo;
import com.huimv.env.common.mapper.BasePigpenMapper;
import com.huimv.env.common.mapper.EnergyDataMapper;
import com.huimv.env.common.mapper.EnergyWaterMapper;
import com.huimv.env.common.service.IEnergyWaterService;
import com.huimv.env.common.utils.Result;
import com.huimv.env.common.utils.ResultCode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author author
 * @since 2023-02-14
 */
@Service
public class EnergyWaterServiceImpl extends ServiceImpl<EnergyWaterMapper, EnergyWater> implements IEnergyWaterService {

    @Autowired
    private BasePigpenMapper basePigpenMapper;
    @Autowired
    private EnergyWaterMapper energyWaterMapper;
    @Autowired
    private EnergyDataMapper dataMapper;

    @Override
    public Result listPigpen(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String id = paramsMap.get("id");//层id
        DateTime dateTime = DateUtil.beginOfDay(new Date());
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        List<PigpenDto> pigpenDtos = energyWaterMapper.listPigpen(farmId, id,sdf.format(dateTime));
        return new Result(ResultCode.SUCCESS, pigpenDtos);
    }

    @Override
    public Result listData(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String type = paramsMap.get("type");
        String startTime = paramsMap.get("startTime");
        String endTime = paramsMap.get("endTime");
        String id = paramsMap.get("id");//单元id

        if (type == null || type == "") {
            type = "3";
        }

        List<EnergyWaterDataVo> energyWaterList = null;
        QueryWrapper<EnergyWater> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_id", farmId).eq("unit_id", id);
        //自定义查询
        if ("4".equals(type)) {
            startTime = startTime + " 00:00:00";
            endTime = endTime + " 23:59:59";
            queryWrapper.between("create_date", startTime, endTime);
            energyWaterList = dataMapper.listDay3(queryWrapper);
        }
        //本年
        else if ("3".equals(type)) {
            DateTime dateTime = DateUtil.beginOfYear(new Date());
            queryWrapper.ge("create_date", dateTime);
            energyWaterList = dataMapper.listYear3(queryWrapper);
        }
        //本月
        else if ("2".equals(type)) {
            Date timesMonthmorning = DataUill.getTimesMonthmorning();
            queryWrapper.ge("create_date", timesMonthmorning);
            energyWaterList = dataMapper.listDay3(queryWrapper);
        }
        //本周
        else if ("1".equals(type)) {
            Calendar calendar = Calendar.getInstance();
            calendar.set(Calendar.DATE, calendar.get(Calendar.DATE) - 7);
            queryWrapper.ge("create_date", calendar.getTime());
            List<EnergyWaterDataVo> energyWaterDataVos = dataMapper.listDay3(queryWrapper);
            energyWaterList = energyWaterDataVos;
        }
        return new Result(ResultCode.SUCCESS, energyWaterList);
    }
}
